// GetDP - Copyright (C) 1997-2019 P. Dular and C. Geuzaine, University of Liege
//
// See the LICENSE.txt file for license information. Please report all
// issues on https://gitlab.onelab.info/getdp/getdp/issues.

#ifndef CAL_SMALLFEM_TERM_OF_FEM_EQUATION_H
#define CAL_SMALLFEM_TERM_OF_FEM_EQUATION_H

#include "ProData.h"
void Cal_SmallFemTermOfFemEquation(struct Element*         Element,
                                   struct EquationTerm*    EquationTerm_P,
                                   struct QuantityStorage* QuantityStorage_P0);
#endif
